MethodChannelAudioMonitor class

Inheritance

Constructors

MethodChannelAudioMonitor()

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

disableNativeListen({required String inputDeviceId}) Future<void>
override
enableNativeListen({required String inputDeviceId, required String outputDeviceId}) Future<void>
override
getInputDevices() Future<List<AudioInputDevice>>
override
getNativeListenConfiguration({required String inputDeviceId}) Future<NativeListenConfiguration>
override
getOutputDevices() Future<List<AudioOutputDevice>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setNativeListenOutputDevice({required String inputDeviceId, required String outputDeviceId}) Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited