AudioMonitorPlatform class abstract
- Inheritance
-
- Object
- PlatformInterface
- AudioMonitorPlatform
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
disableNativeListen(
{required String inputDeviceId}) → Future< void> -
enableNativeListen(
{required String inputDeviceId, required String outputDeviceId}) → Future< void> -
getInputDevices(
) → Future< List< AudioInputDevice> > -
getNativeListenConfiguration(
{required String inputDeviceId}) → Future< NativeListenConfiguration> -
getOutputDevices(
) → Future< List< AudioOutputDevice> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setNativeListenOutputDevice(
{required String inputDeviceId, required String outputDeviceId}) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ AudioMonitorPlatform
-
getter/setter pair