MethodChannelAudioMonitor class

Inheritance

Constructors

MethodChannelAudioMonitor()

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getInputDevices() Future<List<AudioMonitorDevice>>
override
getOutputDevices() Future<List<AudioMonitorDevice>>
override
getState() Future<AudioMonitorState>
override
getVolume() Future<double>
override
isMonitoring() Future<bool>
override
isMuted() Future<bool>
override
mute() Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setVolume(double volume) Future<void>
override
start({required String inputDeviceId, required String outputDeviceId}) Future<void>
override
stop() Future<void>
override
toString() String
A string representation of this object.
inherited
unmute() Future<void>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited