AudioMonitorPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • AudioMonitorPlatform
Implementers

Constructors

AudioMonitorPlatform()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getInputDevices() Future<List<AudioMonitorDevice>>
getOutputDevices() Future<List<AudioMonitorDevice>>
getState() Future<AudioMonitorState>
getVolume() Future<double>
isMonitoring() Future<bool>
isMuted() Future<bool>
mute() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setVolume(double volume) Future<void>
start({required String inputDeviceId, required String outputDeviceId}) Future<void>
stop() Future<void>
toString() String
A string representation of this object.
inherited
unmute() Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance AudioMonitorPlatform
getter/setter pair